import create from 'dd-store'
import exampleStore from '/stores/exampleStore'
import { getDynamicTip, addSchedule, delFile, getDynamic, deleteSchedule, getScheduleDetail, uploadPermissions, previewPermissions } from '../../api/request.js'
create.Page({
  store: exampleStore,
  useAll: true,
  data: {
    title: '',
    location: '',
    time1: '',
    time2: '',
    weeks: ['周一', '周二', '周三', '周四', '周五', '周六', '周日'],
    week: '',
    isAcrossDay: true,
    uploadSpaceId: '',
    previewSpaceId: '',
    scheduleItem: '',
    planDate: '',
    allFileInfo: '',
    scheduleTemplateId: '',
    getDynamicTip: [],
    meetingLogId: '',
    organizer: '',
    pemissions: '',
    isRepeatable: '',
    recModel: '',
    showPage: false
  },
  onLoad(event) {
    let scheduleItem = JSON.parse(event.scheduleItem)
    this.setData({
      scheduleItem: scheduleItem,
      pemissions: getApp().globalData.userid
    })
  },
  onShow() {
    this.setData({
      meetingLogId: ''
    })
    let data = {
      id: this.data.scheduleItem.id,
      planDate: this.data.scheduleItem.planDate,
      templateId: this.data.scheduleItem.scheduleTemplateId
    }
    getScheduleDetail(data).then(res => {
      this.setData({
        title: res.data.data.title,
        isRepeatable: res.data.data.repeatable,
        location: res.data.data.location,
        time1: res.data.data.startTime,
        time2: res.data.data.endTime,
        organizer: res.data.data.organizer,
        recModel: res.data.data.recurrenceModel,
        week: this.data.weeks[new Date(res.data.data.startTime).getDay() - 1]
      })
      this.store.data.userList = res.data.data.userList
      this.store.data.aheadTimes = res.data.data.aheadTimes
      this.store.data.remark = res.data.data.remark
      this.acrossDay(res.data.data.startTime, res.data.data.endTime)
      this.update()
      return uploadPermissions()
    }).then(res => {
      this.setData({
        uploadSpaceId: res.data.data
      })
    })
    // 获取动态详情
    if (!!this.data.scheduleItem.id) {
      this.showFile(this.data.scheduleItem.id)
    } else {
      let getId = {
        scheduleTemplateId: this.data.scheduleItem.scheduleTemplateId,
        planDate: this.data.scheduleItem.planDate,
        createModel: 'auto'
      }
      addSchedule(getId).then(success => {
        this.showFile(success.data.id)
      })
    }
  },
  // 是否跨天
  acrossDay(time1, time2) {
    let isAcrossDay = ''
    if (JSON.stringify(this.dealTime(time1)) === JSON.stringify(this.dealTime(time2))) {
      isAcrossDay = false
    } else {
      isAcrossDay = true
    }
    this.setData({
      isAcrossDay: isAcrossDay
    })
  },
  // 处理时间
  dealTime(time) {
    let time1 = time.replace(/-/g, "/")
    let date = new Date(time1)
    let day = date.getDate()
    let year = date.getFullYear()
    let month = date.getMonth() + 1
    return {
      year: year,
      month: month,
      day: day
    }
  },
  // 上传文件
  upload() {
    const _that = this
    dd.uploadAttachmentToDingTalk({
      image: { multiple: true, compress: true, max: 9, spaceId: _that.data.uploadSpaceId },
      space: { spaceId: _that.data.uploadSpaceId, compress: true, isCopy: 1, max: 9 },
      types: ["photo", "camera", "space"],
      success: (res) => {
        console.log(111111)
        console.log(JSON.stringify(res))
        console.log(2222)
        dd.navigateTo({ url: `./../uploadFile/uploadFile?scheduleItem=${JSON.stringify(_that.data.scheduleItem)}&upLoadInfo=${JSON.stringify(res)}` })
      },
      fail: (err) => {
        dd.alert({
          content: JSON.stringify(err)
        })
      }
    })
  },
  // 文件预览
  preview(event) {
    const _that = this
    let file = event.target.dataset.file
    previewPermissions(file.fileId).then(res => {
      _that.setData({
        previewSpaceId: res.data.data
      })
      dd.previewFileInDingTalk({
        corpId: dd.corpId,
        spaceId: _that.data.previewSpaceId,
        fileId: file.fileId,
        fileName: file.fileName,
        fileSize: file.fileSize,
        fileType: file.fileType
      })
    })
  },
  // 删除文件
  delFile(event) {
    const _that = this
    this.setData({
      meetingLogId: ''
    })
    let data = event.target.dataset.file.id
    dd.confirm({
      title: '温馨提示',
      content: '确认删除本次上传文件吗',
      confirmButtonText: '确定',
      cancelButtonText: '取消',
      success: (success) => {
        if (!!success.confirm) {
          if (!!this.data.scheduleItem.id) {
            delFile(data).then(res => {
              _that.showFile(this.data.scheduleItem.id)
            })
          } else {
            let getId = {
              scheduleTemplateId: _that.data.scheduleItem.scheduleTemplateId,
              planDate: _that.data.scheduleItem.planDate,
              createModel: 'auto'
            }
            addSchedule(getId).then(success => {
              delFile(data).then(res => {
                _that.showFile(success.data.id)
              })
            })
          }
        }
      }
    })
  },
  // 展示文件动态信息
  showFile(id) {
    let data = {
      scheduleId: id,
    }
    getDynamic(data).then(res => {
      let allFileInfo = []
      if (!!res.data.data) {
        res.data.data.forEach((item, index) => {
          item.time = this.dealFileTime(item.createTime)
          if (!!item.scheduleAccessory) {
            item.scheduleAccessory.time = this.dealFileTime(item.createTime)
            item.scheduleAccessory.fileInfos = JSON.parse(item.scheduleAccessory.fileInfos)
            item.scheduleAccessory.uploaderInfo = JSON.parse(item.scheduleAccessory.uploaderInfo)
          }
          allFileInfo.push(item)
        })
      }
      this.setData({
        allFileInfo: allFileInfo
      })
      setTimeout(() => {
        this.setData({
          showPage: true
        })
      }, 300)
    })
  },
  touchStart(event) {
  },
  onTouchEnd(event) {
  },
  // 长按事件
  longPress(event) {
    this.setData({
      meetingLogId: event.target.dataset.id
    })
  },
  // 跳转下一页
  nextPage(event) {
    switch (event.target.dataset.nextPage) {
      case 'participants':
        dd.navigateTo({ url: `./../attendingSituation/attendingSituation?userList=${JSON.stringify(this.store.data.userList)}` })
        break;
      case 'edit':
        dd.navigateTo({ url: `./../createOrEditSchedule/createOrEditSchedule?scheduleItem=${JSON.stringify(this.data.scheduleItem)}` })
        break;
      case 'editFile':
        console.log(event.target.dataset.file)
        this.setData({
          meetingLogId: ''
        })
        dd.navigateTo({ url: `./../editFile/editFile?file=${JSON.stringify(event.target.dataset.file)}` })
        break;
    }
  },
  // 判断是刚刚 五分钟以内 十分钟以内 正常时间年月日
  dealFileTime(creatTime) {
    creatTime = creatTime.replace(/\-/g, "/")
    let nowTime = new Date().getTime()
    let time = new Date(creatTime).getTime()
    let timeResule = ''
    if ((nowTime - time) / 1000 < 60) {
      timeResule = '刚刚'
    } else if ((nowTime - time) / 1000 < 60 * 5 || (nowTime - time) / 1000 == 60) {
      timeResule = '5分钟以内'
    } else {
      timeResule = creatTime.substring(0, 16)
    }
    return timeResule

  }
});
